extensions [
  nw
]

breed [Firms Firm]
breed [Targeters Targeter]
undirected-link-breed [InterFirms InterFirm] ;links between Firms
undirected-link-breed [Adopters Adopter] ;links between Targeter and Firm once they adopt
links-own [weight]
Firms-own [
  EO ;environmental orientation
  AT ;adoption threshold environmental orientation
  PP ;peer pressure of firm based on weighted percent of neighbors who have adopted
  IT ;information threshold peer pressure
  degree ;measures degree centrality of Firm
  influence ;measures influence of Firm in terms of average weight of InterFirm links
  betweenness ;measures betweenness centrality of Firm
  informed ;takes on two values depending on how the Firm was informed about the eco-innovation "targeting" "peer pressure"
  threshold? ;if firm adoption decision has crossed threshold
  adopt? ;if firm has adopted
  adoptthisstep? ;if firm adopts this step
]

globals [
  timetomax ;how long it takes to get to max adoption
  firmsapproached ;number of firms approached by targeting
  numadopters ;number of cumulative adopters at a time step
  potadopters; number of potential adopters at a time step
  Peerpressureadopters ;number of Firms adopted due to peer pressure
  Targetingapproachadopters ;number of Firms approached by targeting who adopted
  Adoptdegree ;degree of Firm approached by targeting who adopted
  Adoptinfluence ;avg InterFirm link weight of Firm approached by targeting who adopted
  Allpp ;avg PP of all Firms
  firmnetworkcomponent ;shows the connected network components of firms
  potentialadoptioncomponent ;shows the connected network components of potential adopters
  adoptioncomponent ;shows the connected network components of adopters
  endrun? ;notifies model to stop
]

to setup
  clear-all
  random-seed seed
  set timetomax ""
  set firmsapproached 0
  set numadopters 0
  set potadopters 0
  set Peerpressureadopters 0
  set Targetingapproachadopters 0
  set Adoptdegree 0
  set Adoptinfluence 0
  set Allpp 0
  set firmnetworkcomponent 0
  set potentialadoptioncomponent 0
  set adoptioncomponent 0
  set endrun? false
  set-default-shape turtles "circle"
  ask patches [
    set pcolor white
  ]
  create-firm-network
  set-initial-firm-parameters
  create-Targeters 1 [
    setxy 0 0
    set color red
  ]
  reset-ticks
end

to create-firm-network ;networks are created such that there is a single connected network component of firms except in the "Multiple Component" case
  (if-else
    network_structure = "Random" [
      while [nw:mean-path-length = false] [
        ask turtles [die]
        create-Firms number-of-firms
        while [ count InterFirms < (average-degree / 2 * number-of-firms)] [
          ask one-of turtles [
            create-InterFirm-with one-of other turtles
          ]
        ]
      ]
    ]
    network_structure = "Scale-Free" [
      while [nw:mean-path-length = false] [
        ask turtles [die]
        let links-per-agent average-degree / 2
        let initial-number-of-agents 2 * links-per-agent + 1
        let initial-number-of-links initial-number-of-agents * (initial-number-of-agents - 1) / 2
        create-Firms initial-number-of-agents [
          create-InterFirms-with other Firms
        ]
        create-Firms number-of-firms - initial-number-of-agents [
          repeat links-per-agent [
            let new-neighbor [one-of both-ends] of one-of InterFirms
            while [member? new-neighbor InterFirm-neighbors or new-neighbor = self] [
              set new-neighbor [one-of both-ends] of one-of InterFirms
            ]
            create-InterFirm-with new-neighbor
          ]
        ]
      ]
    ]
    network_structure = "Small World" [
      while [nw:mean-path-length = false] [
        ask turtles [die]
        nw:generate-watts-strogatz Firms InterFirms number-of-firms (average-degree / 2) 0.2
      ]
    ]
    network_structure = "Small World Multiple Component" [ ;repeatedly generates Small World networks until there is are a specified number of connected network components of firms
      while [firmnetworkcomponent != num-component] [
        ask turtles [die]
        nw:generate-watts-strogatz Firms InterFirms number-of-firms (average-degree / 2) 0.2
        nw:set-context Firms InterFirms
        set firmnetworkcomponent length nw:weak-component-clusters ;calculates the number of connected network components of firms
      ]
    ]
  )
  ask Firms [set color black]
  ask InterFirms [
    set weight random-float 1 ;create weights for links to signify strength of relationship between Firms
    set thickness weight / 3 ;shows weights as thicker lines
  ]
  if behaviorspace-run-number = 0 [repeat 100 [layout-spring Firms InterFirms 5 10 50]] ;layout messes up randomization, so if recreating Behaviorspace results in interface, comment this out and run at the end
end

to set-initial-firm-parameters
  ask Firms [
    set EO random-normal 0.5 0.1 ;following EcoVadis 2020 report on CSR scores of companies globally
    set AT adoption-threshold ;global threshold for all firms specified by slider
    set PP 0
    set IT information-threshold ;global threshold for all firms specified by slider
    set degree count my-InterFirms
    if any? my-InterFirms [set influence mean [weight] of my-InterFirms]
    set betweenness nw:betweenness-centrality
    set informed "none"
    set threshold? false
    set adopt? false
    set adoptthisstep? false
    threshold-calculate
  ]
  nw:set-context Firms InterFirms
  set firmnetworkcomponent length nw:weak-component-clusters ;calculates the number of connected network components of firms
  set potadopters count Firms with [threshold? = true] ; potential adopters are ones who are ready to adopt at step 0 without any peer pressure
  nw:set-context Firms with [threshold? = true] InterFirms
  set potentialadoptioncomponent length nw:weak-component-clusters ;calculates the number of connected network components of potential adopters
end

to go
  if endrun? = true [stop]
  if any? Firms with [informed = "none"] [targeting-approach] ;Information-phase: Network-based Targeting + Adoption-phase
  ask Firms with [adopt? = false] [peer-pressure] ;Information-phase: Connected Neighbors + Adoption-phase
  reporters
  ask Firms [set adoptthisstep? false] ;resets to only capture data for adopters of the single time step
  tick
end

to targeting-approach ;Information-phase: Network-based Targeting + Adoption-phase
  let adoptfirmswithneighbors Firms with [adopt? = true and any? InterFirm-neighbors with [informed = "none"]] ;neighbors of adopters
  (ifelse
    targeting_strategy = "Random" [ask one-of Firms with [informed = "none"] [set informed "targeting approach" adoption-decision ]] ;Targeter picks Firms at random
    targeting_strategy = "High Degree" [ask one-of Firms with [informed = "none"] with-max [degree] [set informed "targeting approach" adoption-decision ]] ;Targeter picks Firms with a high degree centrality that haven't been approached already
    targeting_strategy = "High Influence" [ask one-of Firms with [informed = "none"] with-max [influence] [set informed "targeting approach" adoption-decision ]] ;Targeter picks Firms with a high influence that haven't been approached already
    targeting_strategy = "High Betweenness" [ask one-of Firms with [informed = "none"] with-max [betweenness] [set informed "targeting approach" adoption-decision ]] ;Targeter picks Firms with a high betweenness that haven't been approached already
    targeting_strategy = "Random Neighbor" [ ; Targeter randomly picks firms if no one has adopted, otherwise they will pick a random neighbor to the Firm that has adopted
      ifelse any? adoptfirmswithneighbors
        [ask one-of adoptfirmswithneighbors [
          let randomneighbor one-of InterFirm-neighbors with [informed = "none"]
          ask randomneighbor [set informed "targeting approach" adoption-decision ]]]
        [ask one-of Firms with [informed = "none"] [set informed "targeting approach" adoption-decision ]] ;if there are no adopted Firms with neighbors that haven't been approached, pick someone at random
    ]
    targeting_strategy = "Degree Neighbor" [ ; Targeter randomly picks firms if no one has adopted, otherwise they will pick a high degree neighbor to the Firm that has adopted
      ifelse any? adoptfirmswithneighbors
        [ask one-of adoptfirmswithneighbors [
          let degreeneighbor max-one-of InterFirm-neighbors with [informed = "none"] [degree]
          ask degreeneighbor [set informed "targeting approach" adoption-decision ]]]
        [ask one-of Firms with [informed = "none"] [set informed "targeting approach" adoption-decision ]] ;if there are no adopted Firms with neighbors that haven't been approached, pick someone at random
    ]
    targeting_strategy = "Influence Neighbor" [ ; Targeter randomly picks firms if no one has adopted, otherwise they will pick a highly influential neighbor to the Firm that has adopted
      ifelse any? adoptfirmswithneighbors
        [ask one-of adoptfirmswithneighbors [
          let influenceneighbor max-one-of InterFirm-neighbors with [informed = "none"] [influence]
          ask influenceneighbor [set informed "targeting approach" adoption-decision ]]]
        [ask one-of Firms with [informed = "none"] [set informed "targeting approach" adoption-decision ]] ;if there are no adopted Firms with neighbors that haven't been approached, pick someone at random
    ]
  )
end

to adoption-decision
  threshold-calculate ;when firms decide to adopt, they determine whether they have exceeded their adoption threshold
  if threshold? = true [ ;if the threshold is exceeded, then they adopt
    set adopt? true
    set adoptthisstep? true
    ifelse informed = "targeting approach" ;different colors for whether the firm adopted because of targeting or because of peer pressure
      [set color green create-Adopter-with one-of Targeters [set color green set thickness .2]]
      [set color 58 create-Adopter-with one-of Targeters [set color 58 set thickness .2]]
  ]
end

to threshold-calculate ;adoption threshold is calculated based on internal environmental orientation + peer pressure as in Delre et. al, 2010
  if any? my-InterFirms [set PP sum [weight] of my-InterFirms with [[adopt? = true] of other-end ] / sum [weight] of my-InterFirms] ;calculates weighted share of InterFirm neighbors who have adopted
  if AT < (EO + PP) / 2 [ set threshold? true set color blue]
end

to peer-pressure ;Information-phase: Connected Neighbors + Adoption-phase
  if any? my-InterFirms [set PP sum [weight] of my-InterFirms with [[adopt? = true] of other-end ] / sum [weight] of my-InterFirms] ;fractional threshold as  weighted share of InterFirm neighbors who have adopted as in Watts, 2002; Centola and Macy, 2007
  if IT < PP [ ;if peer pressure exceeds the information threshold set globally, then firm will consider adoption
    set informed "peer pressure"
    adoption-decision
  ]
end

to reporters ;reporters to understand the dynamics of the model
  set firmsapproached count Firms with [informed = "targeting approach"] ;firms approached by targeting
  set numadopters count Firms with [adopt? = true] ;number of adopters
  set potadopters count Firms with [threshold? = true] ;number of potential adopters
  nw:set-context Firms with [threshold? = true] InterFirms
  set potentialadoptioncomponent length nw:weak-component-clusters ;calculates how many connected network components the potential adopters form
  nw:set-context Firms with [adopt? = true] InterFirms
  set adoptioncomponent length nw:weak-component-clusters ;calculates how many connected network components the adopters form
  set Peerpressureadopters count Firms with [informed = "peer pressure" and adopt? = true] ;how many firms adopted because of peer pressure
  set Targetingapproachadopters count Firms with [informed = "targeting approach" and adopt? = true] ;how many firms adopted because of targeting
  if any? Firms with [adoptthisstep? = true][
    set Adoptdegree mean [degree] of Firms with [adoptthisstep? = true] ;degree of firms that adopted at a particular time-step
    set Adoptinfluence mean [influence] of Firms with [adoptthisstep? = true] ;influence of firms that adopted at a particular time-step
  ]
  set Allpp mean [PP] of Firms ;peer pressure of all Firms at each time-step
  if count Firms with [adopt? = true] = count Firms with [threshold? = true] and timetomax = "" [ ;calculates the time to maximum possible adoption
    set timetomax ticks
  ]
  if ticks = number-of-firms [set endrun? true] ;model runs until the time = number-of-firms
end
@#$#@#$#@
GRAPHICS-WINDOW
282
18
659
396
-1
-1
11.2
1
10
1
1
1
0
0
0
1
-16
16
-16
16
1
1
1
ticks
30.0

BUTTON
118
317
181
350
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
193
317
256
350
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

TEXTBOX
776
10
1333
122
Diffusion of Eco-Innovation through Inter-firm Network Targeting Strategies: An Agent-Based Model
25
0.0
1

CHOOSER
15
179
253
224
network_structure
network_structure
"Random" "Scale-Free" "Small World" "Small World Multiple Component"
2

CHOOSER
15
264
255
309
targeting_strategy
targeting_strategy
"Random" "High Degree" "High Betweenness" "High Influence" "Random Neighbor" "Degree Neighbor" "Influence Neighbor"
6

PLOT
790
152
1229
302
Adoption Curve
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -10899396 true "" "plot numadopters"
"pen-1" 1.0 0 -7500403 true "" "plot potadopters"

PLOT
790
371
1231
491
Environmental Orientation
NIL
NIL
0.0
1.0
0.0
1.0
true
false
"" ""
PENS
"default" 0.1 1 -16777216 true "" "histogram [EO] of Firms"

MONITOR
51
443
226
488
Targeting approach adopters
Targetingapproachadopters
17
1
11

MONITOR
609
420
706
465
InterFirm Ties
count Interfirms
17
1
11

MONITOR
606
530
710
575
Average Degree
mean [count my-InterFirms] of Firms
2
1
11

PLOT
347
407
579
527
Degree Distribution
NIL
NIL
0.0
70.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "histogram [degree] of Firms"

PLOT
349
532
578
653
InterFirm Weights Distribution
NIL
NIL
0.0
1.0
0.0
1.0
true
false
"" ""
PENS
"default" 0.1 1 -16777216 true "" "histogram [weight] of InterFirms"

MONITOR
51
499
224
544
Peer pressure adopters
Peerpressureadopters
17
1
11

SLIDER
15
16
252
49
number-of-firms
number-of-firms
0
500
100.0
10
1
NIL
HORIZONTAL

MONITOR
609
474
704
519
Reciprocal Ties
2 * count InterFirms
17
1
11

MONITOR
605
589
709
634
Network Density
count InterFirms / (number-of-firms * (number-of-firms - 1) / 2)
3
1
11

INPUTBOX
27
316
103
376
seed
5.0
1
0
Number

MONITOR
161
612
295
657
NIL
adoptioncomponent
17
1
11

MONITOR
160
559
331
604
NIL
potentialadoptioncomponent
17
1
11

BUTTON
187
355
262
388
go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
790
504
1233
624
Average weight of ClientFirm ties
NIL
NIL
0.0
1.0
0.0
10.0
true
false
"" ""
PENS
"default" 0.1 1 -16777216 true "" "histogram [mean [weight] of my-InterFirms] of Firms"

SLIDER
15
56
253
89
average-degree
average-degree
0
8
4.0
1
1
NIL
HORIZONTAL

MONITOR
1109
308
1231
353
potential adopters
potadopters
17
1
11

MONITOR
1042
308
1105
353
adopters
numadopters
17
1
11

SLIDER
15
97
252
130
adoption-threshold
adoption-threshold
0
1
0.3
.01
1
NIL
HORIZONTAL

SLIDER
15
138
254
171
information-threshold
information-threshold
0
1
0.6
.1
1
NIL
HORIZONTAL

MONITOR
52
392
230
437
Firms approached by targeter
firmsapproached
17
1
11

MONITOR
14
560
154
605
NIL
firmnetworkcomponent
17
1
11

SLIDER
15
227
254
260
num-component
num-component
0
10
3.0
1
1
NIL
HORIZONTAL

@#$#@#$#@
This model is developed as a theoretical agent-based model to study the general phenomena of network-based targeting strategies on eco-innovation adoption and diffusion through inter-firm networks.

During the initialization of the model, firms are populated based on a specified number of firms in the network. Each firm is assigned an Environmental Orientation [EO] factor that represents the firm’s internal factors for adopting the eco-innovation, drawn from a random normal distribution with a mean of 0.5 and a standard deviation of 0.1. The model constructs theoretically generated networks of firms using the Erdős–Rényi Random Network, Barabási–Albert Scale-Free Network, and Watts-Strogatz Small World Network models. The links between firms are assumed to be partnerships, collaborative alliances, and the exchange of knowledge and information connected through collaborative relationships. The links between the firms are assigned a non-zero weight from 0 to 1, drawn from a random uniform distribution, to reflect the strength of the relationship between the firms.

After the initialization of the model, the simulation follows a two-phase information and adoption process. First, in the information phase, firms need information about the existence of the eco-innovation, which occurs through network-based targeting or if contact with their connected neighbors exceeds a certain globally defined information threshold. We assume that firms have no prior knowledge of the eco-innovation and are informed by an agent outside the network using one of 6 network-based targeting strategies. At every time step, each firm that has not adopted the eco-innovation and not targeted by the network-based targeting strategy will be exposed to connected neighbor firms that have adopted. If the link-weighted percent of connected neighbor firms who have adopted [PP] exceeds a globally specified information threshold [IT], then the firms will be informed about the eco-innovation. Once informed, the firms decide to adopt the eco-innovation if the average of their internal factors, EO, and their external pressures from peers that have adopted, PP, exceeds a globally specified adoption threshold. 

The model runs multiple simulations in Behaviorspace for each of the network-based targeting strategies and under various network structures and parameters – varying thresholds for adoption and diffusion, varying network degree, varying network size, and varying clusters of firms. To account for randomization, the model is run 1000 times for every combination of model parameter and the results are averaged to compare the average number of adopters under the different network-based strategies.

The model output and more detailed documentation is part of a manuscript, which is currently under review.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="varythresholds" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>timetomax</metric>
    <metric>firmsapproached</metric>
    <metric>numadopters</metric>
    <metric>potadopters</metric>
    <metric>Peerpressureadopters</metric>
    <metric>Targetingapproachadopters</metric>
    <metric>Adoptdegree</metric>
    <metric>Adoptinfluence</metric>
    <metric>Allpp</metric>
    <metric>potentialadoptioncomponent</metric>
    <metric>adoptioncomponent</metric>
    <enumeratedValueSet variable="number-of-clients">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adoption-threshold">
      <value value="0.25"/>
      <value value="0.27"/>
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="informed-threshold">
      <value value="0.4"/>
      <value value="0.5"/>
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="startup_strategy">
      <value value="&quot;Random&quot;"/>
      <value value="&quot;High Degree&quot;"/>
      <value value="&quot;High Betweenness&quot;"/>
      <value value="&quot;High Influence&quot;"/>
      <value value="&quot;Random Neighbor&quot;"/>
      <value value="&quot;Degree Neighbor&quot;"/>
      <value value="&quot;Influence Neighbor&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network_topology">
      <value value="&quot;Random&quot;"/>
      <value value="&quot;Scale-Free&quot;"/>
      <value value="&quot;Small World&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-cluster">
      <value value="1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="seed" first="1" step="1" last="1000"/>
  </experiment>
  <experiment name="varyfirms" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>timetomax</metric>
    <metric>firmsapproached</metric>
    <metric>numadopters</metric>
    <metric>potadopters</metric>
    <metric>Peerpressureadopters</metric>
    <metric>Targetingapproachadopters</metric>
    <metric>Adoptdegree</metric>
    <metric>Adoptinfluence</metric>
    <metric>Allpp</metric>
    <metric>potentialadoptioncomponent</metric>
    <metric>adoptioncomponent</metric>
    <enumeratedValueSet variable="number-of-clients">
      <value value="50"/>
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adoption-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="informed-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="startup_strategy">
      <value value="&quot;Random&quot;"/>
      <value value="&quot;High Degree&quot;"/>
      <value value="&quot;High Influence&quot;"/>
      <value value="&quot;High Betweenness&quot;"/>
      <value value="&quot;Random Neighbor&quot;"/>
      <value value="&quot;Degree Neighbor&quot;"/>
      <value value="&quot;Influence Neighbor&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network_topology">
      <value value="&quot;Random&quot;"/>
      <value value="&quot;Scale-Free&quot;"/>
      <value value="&quot;Small World&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-cluster">
      <value value="1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="seed" first="1" step="1" last="1000"/>
  </experiment>
  <experiment name="varylinks" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>timetomax</metric>
    <metric>firmsapproached</metric>
    <metric>numadopters</metric>
    <metric>potadopters</metric>
    <metric>Peerpressureadopters</metric>
    <metric>Targetingapproachadopters</metric>
    <metric>Adoptdegree</metric>
    <metric>Adoptinfluence</metric>
    <metric>Allpp</metric>
    <metric>potentialadoptioncomponent</metric>
    <metric>adoptioncomponent</metric>
    <enumeratedValueSet variable="number-of-clients">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="4"/>
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adoption-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="informed-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="startup_strategy">
      <value value="&quot;Random&quot;"/>
      <value value="&quot;High Degree&quot;"/>
      <value value="&quot;High Influence&quot;"/>
      <value value="&quot;High Betweenness&quot;"/>
      <value value="&quot;Random Neighbor&quot;"/>
      <value value="&quot;Degree Neighbor&quot;"/>
      <value value="&quot;Influence Neighbor&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network_topology">
      <value value="&quot;Random&quot;"/>
      <value value="&quot;Scale-Free&quot;"/>
      <value value="&quot;Small World&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-cluster">
      <value value="1"/>
    </enumeratedValueSet>
    <steppedValueSet variable="seed" first="1" step="1" last="1000"/>
  </experiment>
  <experiment name="varyclusters" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>timetomax</metric>
    <metric>firmsapproached</metric>
    <metric>numadopters</metric>
    <metric>potadopters</metric>
    <metric>Peerpressureadopters</metric>
    <metric>Targetingapproachadopters</metric>
    <metric>Adoptdegree</metric>
    <metric>Adoptinfluence</metric>
    <metric>Allpp</metric>
    <metric>firmcluster</metric>
    <metric>potentialadoptioncomponent</metric>
    <metric>adoptioncomponent</metric>
    <enumeratedValueSet variable="number-of-clients">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-degree">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="adoption-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="informed-threshold">
      <value value="0.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="startup_strategy">
      <value value="&quot;Random&quot;"/>
      <value value="&quot;High Degree&quot;"/>
      <value value="&quot;High Influence&quot;"/>
      <value value="&quot;High Betweenness&quot;"/>
      <value value="&quot;Random Neighbor&quot;"/>
      <value value="&quot;Degree Neighbor&quot;"/>
      <value value="&quot;Influence Neighbor&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="network_topology">
      <value value="&quot;Small World Multiple Cluster&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-cluster">
      <value value="3"/>
      <value value="5"/>
    </enumeratedValueSet>
    <steppedValueSet variable="seed" first="1" step="1" last="1000"/>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
